==> Ver%203.0.0.zip: Ver 3.0.0/src/jp/mosp/human/vo/HumanCardVo.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2008 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.human.vo;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.common.CommonConst;
import jp.mosp.common.vo.MosPVo;

public abstract class HumanCardVo extends MosPVo {

	// p[^
	public static final String PRM_TXT_CHANGE_K_CODE   = "txtChangeKCode";
	public static final String PRM_HID_SELECT_LIST_CMD = "hidSelectListCmd";

	// tB[h
	protected String txtChangeKCode;
	protected String lblKCode;
	protected String lblKName;
	protected String lblKKana;

	// tB[hyѐ
	public static final String NAM_HUMAN_INFO	= CommonConst.NAM_HUMAN_INFO + CommonConst.NAM_MENU;

	// {^eύX
	private String cmdListButton1;
	private String namListButton1;

	private String hidSelectListCmd ;

	/**
	 * RXgN^
	 */
	public HumanCardVo() {
		super();
	}

	/**
	 * p[^ݒ
	 * @param request NGXg
	 */
	public void setParams(HttpServletRequest request) {
		txtChangeKCode    = request.getParameter(PRM_TXT_CHANGE_K_CODE);
		hidSelectListCmd  = request.getParameter(PRM_HID_SELECT_LIST_CMD);
	}

	/**
	 * p[^
	 */
	public void initFields() {
		txtChangeKCode = "";
	}

	// ANZT\bh
	public String getTxtChangeKCode   () { return txtChangeKCode            ; }
	public String getLblKCode         () { return lblKCode                  ; }

	public String getEscTxtChangeKCode() { return escapeHTML(txtChangeKCode); }
	public String getEscLblKCode      () { return escapeHTML(lblKCode      ); }
	public String getEscLblKName      () { return escapeHTML(lblKName      ); }
	public String getEscLblKKana      () { return escapeHTML(lblKKana      ); }

	public void   setTxtChangeKCode(String txtChangeKCode) { this.txtChangeKCode = txtChangeKCode; }
	public void   setLblKCode      (String lblKCode      ) { this.lblKCode       = lblKCode      ; }
	public void   setLblKName      (String lblKName      ) { this.lblKName       = lblKName      ; }
	public void   setLblKKana      (String lblKKana      ) { this.lblKKana       = lblKKana      ; }

	public void setCmdListButton1(String cmdListButton1) { this.cmdListButton1 = cmdListButton1; }
	public void setNamListButton1(String namListButton1) { this.namListButton1 = namListButton1; }
	public String getCmdListButton1() {return cmdListButton1; }
	public String getNamListButton1() {return namListButton1; }

	public void setHidSelectListCmd(String hidSelectListCmd) { this.hidSelectListCmd = hidSelectListCmd; }
	public String getHidSelectListCmd() {return hidSelectListCmd; }

}

==> Ver%203.1.1.zip: Ver 3.1.1/src/jp/mosp/human/vo/HumanCardVo.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.human.vo;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPVo;

public abstract class HumanCardVo extends MosPVo {

	// p[^
	public static final String PRM_TXT_CHANGE_K_CODE   = "txtChangeKCode";
	public static final String PRM_HID_SELECT_LIST_CMD = "hidSelectListCmd";

	// tB[h
	protected String txtChangeKCode;
	protected String lblKCode;
	protected String lblKName;
	protected String lblKKana;

	// tB[hyѐ
	public static final String NAM_HUMAN_INFO	= CommonConst.NAM_HUMAN_INFO + CommonConst.NAM_MENU;

	// {^eύX
	private String cmdListButton1;
	private String namListButton1;

	private String hidSelectListCmd ;

	/**
	 * RXgN^
	 */
	public HumanCardVo() {
		super();
	}

	/**
	 * p[^ݒ
	 * @param request NGXg
	 */
	public void setParams(HttpServletRequest request) {
		txtChangeKCode    = request.getParameter(PRM_TXT_CHANGE_K_CODE);
		hidSelectListCmd  = request.getParameter(PRM_HID_SELECT_LIST_CMD);
	}

	/**
	 * p[^
	 */
	public void initFields() {
		txtChangeKCode = "";
	}

	// ANZT\bh
	public String getTxtChangeKCode   () { return txtChangeKCode            ; }
	public String getLblKCode         () { return lblKCode                  ; }

	public String getEscTxtChangeKCode() { return escapeHTML(txtChangeKCode); }
	public String getEscLblKCode      () { return escapeHTML(lblKCode      ); }
	public String getEscLblKName      () { return escapeHTML(lblKName      ); }
	public String getEscLblKKana      () { return escapeHTML(lblKKana      ); }

	public void   setTxtChangeKCode(String txtChangeKCode) { this.txtChangeKCode = txtChangeKCode; }
	public void   setLblKCode      (String lblKCode      ) { this.lblKCode       = lblKCode      ; }
	public void   setLblKName      (String lblKName      ) { this.lblKName       = lblKName      ; }
	public void   setLblKKana      (String lblKKana      ) { this.lblKKana       = lblKKana      ; }

	public void setCmdListButton1(String cmdListButton1) { this.cmdListButton1 = cmdListButton1; }
	public void setNamListButton1(String namListButton1) { this.namListButton1 = namListButton1; }
	public String getCmdListButton1() {return cmdListButton1; }
	public String getNamListButton1() {return namListButton1; }

	public void setHidSelectListCmd(String hidSelectListCmd) { this.hidSelectListCmd = hidSelectListCmd; }
	public String getHidSelectListCmd() {return hidSelectListCmd; }

}
